<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu_HU">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Van élet a böngészőn kívül!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>%1 verzió</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">Ez egy bemutató verzió, nem biztos, hogy tökéletesen működik.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Hibabejelentés, ötletek: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>A %1 szabad szoftver, de a fejlesztés időbe telik és az idő pénz.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">Kérlek &lt;a href=&apos;%1&apos;&gt;adakozz Paypalon keresztül&lt;/a&gt;, hogy segítsd a %2 fejlesztését.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Az ikonokat tervezte: %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Kompakt mód: %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP proxy támogatás: %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Windows verzió: %1</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Fordította: %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Kiadva &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt; alatt</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Amit mindig is tudni akartál a %1-ról, de sosem merted megkérdezni</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Kérlek &lt;a href=&apos;%1&apos;&gt;adakozz&lt;/a&gt;, hogy folytathassam a %2 fejlesztését</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation></translation>
    </message>
    <message>
        <source>KB</source>
        <translation></translation>
    </message>
    <message>
        <source>MB</source>
        <translation></translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation></translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation></translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation></translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>másodperc</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>perc</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 van hátra</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n Letöltés(ek)</numerusform>
        </translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Ez csak a demo verziója a %1-nak.</translation>
    </message>
    <message>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Csak rövidebb, mint %1 perces videókat tudsz letölteni a letöltési funkció ellenőrzéséhez.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tovább</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Szerezd be a teljes verziót</translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Könyvtár módosítása...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Válaszd ki a letöltési könyvtárat</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Letöltési könyvtár megváltoztatva.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Az aktuális letöltések a régi letöltési könyvárba lesznek mentve.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Letöltés a következő könyvtárba: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Letöltések</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szünet</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Lejátszás/Szünet</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Megállítás</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Lejátszás megállítása a jelenlegi videó után</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Következő videó</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Előző videó</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Hangosítás</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Halkítás</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Némítás</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Előre teker</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Hátra teker</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Keresés...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Mutass még %1-et</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nincsenek videók</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nincs több videó</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">&amp;Vissza</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">Vissza az előző nézethez</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Állj</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Megáll és visszamegy a keresőbe</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Kihagyás</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Kihagyja a következő videót</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Szünet</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Szünetelteti a lejátszást</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Teljes képernyő</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Teljes képernyőre teszi a videót</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>K&amp;ompakt mód</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Elrejti a lejátszó listát és az eszköztárat</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation type="obsolete">&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">Megnyitja a YouTube videómegosztó oldalt</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Eltávolítja a kijelölt videókat a listából</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>&amp;Fel</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Előrehozza a kijelölt videókat a listán</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>&amp;Le</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Lejjebb viszi a kijelölt videókat a listán</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Kilépés</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Viszlát</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Weboldal</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 a weben</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">&amp;Adakozás PayPalon keresztül</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Kérlek támogasd a  %1 fejlesztését</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Névjegy</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Információk a %1-ról</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Némítás</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Lejátszó lista</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Segítség</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Nyomd meg a %1 gombot a hangosításhoz, a %2 gombot a halkításhoz</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Megnyitás %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Végzetes hiba: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Hiba: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Lejátszás</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Lejátszás folytatása</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Kilépés a &amp;Teljes képernyőből</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Hátralévő idő: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Hangerő: %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Némítás bekapcsolva</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Némítás kikapcsolva</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="obsolete">HD videó bekapcsolva</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="obsolete">HD videó kikapcsolva</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="obsolete">Ez a videó HD minőségű</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="obsolete">Ez a videó nem HD minőségű</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="obsolete">&amp;Legújabb kulcsszavak törlése</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Alkalmazás</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Keresési előzmények törlése. Nem visszavonható.</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Biztonságban vagy</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>A YouTube megnyitása</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>A YouTube oldalra irányítás és a lejátszás szüneteltetése</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>YouTube link másolása</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Az aktuális YouTube video link másolása vágólapra</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>A video stream &amp;URL másolása</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Az aktuális video stream URL másolása vágólapra</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>A&amp;dakozz</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Maximum videó minőség beállítása %1-ra</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Letöltések</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Videó letöltések részletei</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Letöltés</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Aktuális videó letöltése</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Letöltés van folyamatban. Biztos, hogy ki akarsz lépni a %1-ból?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Ha bezárod a %1-ot, a letöltés megszakad.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Bezárás és a letöltés megszakítása.</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Várakozás a letöltés befejezésére</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Letöltés befejezve</translation>
    </message>
    <message>
        <source>&amp;Clear recent searches</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Kapcsolódó videók</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Legújabbak</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Legnézettebbek</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation type="obsolete">A &quot;%1&quot;-t nézed</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Most már beillesztheted a YouTube linket más alkalmazásba</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Most már beillesztheted a video stream URL-t más alkalmazásba</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>A link korlátozott ideig érvényes</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Ez csak a demo verziója a %1-nak.</translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Lehetőséget nyújt a program kipróbálására.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tovább</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Szerezd be a teljes verziót</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>%1 letöltése</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Hálózati hiba: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1x megtekintve</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Előkészítés</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Sikertelen</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Kész</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Megállítva</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Letöltés megállítása</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Mutasd a %1-ban</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Szülő könyvtár megnyitása</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Letöltés újraindítása</translation>
    </message>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Üdvözöl a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation type="obsolete">Írd be a keresendő kifejezést.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Gyakori kulcsszavak</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>A %1 új verziója elérhető. Kérlek &lt;a href=&apos;%2&apos;&gt;frissíts erre a verzióra: %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Helyezd magad kényelembe</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished">Szerezd be a teljes verziót</translation>
    </message>
    <message>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>a channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Beállítások</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Hálózati hiba: %1 for %2</translation>
    </message>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
